intervaltreetools.compute_logical_and_of_intervals_in_interval
==============================================================

.. autofunction:: abjad.tools.intervaltreetools.compute_logical_and_of_intervals_in_interval
